@@ -24,96 +24,101 @@
 
 #include "config.h"
 
-#include "i18n.h"
-
 #include <unistd.h>
 #include <sys/fcntl.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 #include <iostream>
 #include <cstdio>
 #ifdef HAVE_RPM
 #include <apt-pkg/configuration.h>
 #endif
 
+
 #include "rinstallprogress.h"
 
-void *RInstallProgress::loop(void *data)
-{
-    RInstallProgress *me = (RInstallProgress*)data;
-
-    me->startUpdate();
-    while (me->_thread_id >= 0) 
-	me->updateInterface();
-    me->finishUpdate();
-
-    pthread_exit(NULL);
-    
-    return NULL;
-}
+#include "i18n.h"
 
 
-
-pkgPackageManager::OrderResult RInstallProgress::start(pkgPackageManager *pm,
-						       int numPackages)
+pkgPackageManager::OrderResult RInstallProgress::start(RPackageManager *pm,
+						       int numPackages,
+						       int numPackagesTotal)
 {
     void *dummy;
     pkgPackageManager::OrderResult res;
-
+    int ret;
+    pid_t _child_id;
+    
     //cout << "RInstallProgress::start()" << endl;
- 
+
 #ifdef HAVE_RPM
+
     _config->Set("RPM::Interactive", "false");
     
+    res = pm->DoInstallPreFork();
+    if (res == pkgPackageManager::Failed)
+       return res;
+
     /*
      * This will make a pipe from where we can read child's output
      */
-
-    // our stdout will be _stdout from now on, and our stderr will be _stderr
-    _stdout = dup(1); 
-    _stderr = dup(2);
-
-    // create our comm. channel with the child
     int fd[2];
     pipe(fd);
 
-    // make the write end of the pipe to the child become the new stdout 
-    // and stderr (for the child)
-    dup2(fd[1],1);
-    dup2(1,2);
+    _child_id = fork();
+ 
+    if (_child_id == 0) {
+	// make the write end of the pipe to the child become the new stdout 
+	// and stderr (for the child)
+	dup2(fd[1],1);
+	dup2(1,2);
+	close(fd[0]);
+	close(fd[1]);
 
-    close(fd[1]);
+	res = pm->DoInstallPostFork();
+
+	_exit(res);
+    }
 
     // this is where we read stuff from the child
     _childin = fd[0];
+    close(fd[1]);
 
     // make it nonblocking
     fcntl(_childin, F_SETFL, O_NONBLOCK);
-#endif /* HAVE_RPM */
 
     _donePackages = 0;
     _numPackages = numPackages;
+    _numPackagesTotal = numPackagesTotal;
 
-    // We must reset the _thread_id *before* calling pthread_create(),
-    // otherwise the loop might test for its value before that function
-    // returned. 
-    // this isn't a thread-id, it more a thread-flag
-    _thread_id = 0;
-    _thread_id = pthread_create(&_thread, NULL, loop, this);
-    res = pm->DoInstall();
+#else
 
-    _thread_id = -1;
-    pthread_join(_thread, &dummy);
+    res = pm->DoInstallPreFork();
+    if (res == pkgPackageManager::Failed)
+       return res;
+
+    _child_id = fork();
+ 
+    if (_child_id == 0) {
+	res = pm->DoInstallPostFork();
+	_exit(res);
+    }
+
+#endif
+
+    startUpdate();
+    while (waitpid(_child_id, &ret, WNOHANG) == 0)
+	updateInterface();
+
+    res = (pkgPackageManager::OrderResult)WEXITSTATUS(ret);
+    
+    finishUpdate();
 
 #ifdef HAVE_RPM
-    /*
-     * Clean-up stuff so that everything is like before
-     */
     close(_childin);
-    dup2(_stdout, 1);
-    dup2(_stderr, 2);
-    close(_stdout);
-    close(_stderr);
-#endif /* HAVE_RPM */
+#endif
 
     return res;
 }
 
+// vim:sts=4:sw=4
